# coding: utf-8

"""
InfluxDB OSS API Service.

The InfluxDB v2 API provides a programmatic interface for all interactions with InfluxDB. Access the InfluxDB API using the `/api/v2/` endpoint.   # noqa: E501

OpenAPI spec version: 2.0.0
Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401


class Cell(object):
    """NOTE: This class is auto generated by OpenAPI Generator.

    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'links': 'CellLinks',
        'x': 'int',
        'y': 'int',
        'w': 'int',
        'h': 'int',
        'view_id': 'str'
    }

    attribute_map = {
        'id': 'id',
        'links': 'links',
        'x': 'x',
        'y': 'y',
        'w': 'w',
        'h': 'h',
        'view_id': 'viewID'
    }

    def __init__(self, id=None, links=None, x=None, y=None, w=None, h=None, view_id=None):  # noqa: E501,D401,D403
        """Cell - a model defined in OpenAPI."""  # noqa: E501
        self._id = None
        self._links = None
        self._x = None
        self._y = None
        self._w = None
        self._h = None
        self._view_id = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if links is not None:
            self.links = links
        if x is not None:
            self.x = x
        if y is not None:
            self.y = y
        if w is not None:
            self.w = w
        if h is not None:
            self.h = h
        if view_id is not None:
            self.view_id = view_id

    @property
    def id(self):
        """Get the id of this Cell.

        :return: The id of this Cell.
        :rtype: str
        """  # noqa: E501
        return self._id

    @id.setter
    def id(self, id):
        """Set the id of this Cell.

        :param id: The id of this Cell.
        :type: str
        """  # noqa: E501
        self._id = id

    @property
    def links(self):
        """Get the links of this Cell.

        :return: The links of this Cell.
        :rtype: CellLinks
        """  # noqa: E501
        return self._links

    @links.setter
    def links(self, links):
        """Set the links of this Cell.

        :param links: The links of this Cell.
        :type: CellLinks
        """  # noqa: E501
        self._links = links

    @property
    def x(self):
        """Get the x of this Cell.

        :return: The x of this Cell.
        :rtype: int
        """  # noqa: E501
        return self._x

    @x.setter
    def x(self, x):
        """Set the x of this Cell.

        :param x: The x of this Cell.
        :type: int
        """  # noqa: E501
        self._x = x

    @property
    def y(self):
        """Get the y of this Cell.

        :return: The y of this Cell.
        :rtype: int
        """  # noqa: E501
        return self._y

    @y.setter
    def y(self, y):
        """Set the y of this Cell.

        :param y: The y of this Cell.
        :type: int
        """  # noqa: E501
        self._y = y

    @property
    def w(self):
        """Get the w of this Cell.

        :return: The w of this Cell.
        :rtype: int
        """  # noqa: E501
        return self._w

    @w.setter
    def w(self, w):
        """Set the w of this Cell.

        :param w: The w of this Cell.
        :type: int
        """  # noqa: E501
        self._w = w

    @property
    def h(self):
        """Get the h of this Cell.

        :return: The h of this Cell.
        :rtype: int
        """  # noqa: E501
        return self._h

    @h.setter
    def h(self, h):
        """Set the h of this Cell.

        :param h: The h of this Cell.
        :type: int
        """  # noqa: E501
        self._h = h

    @property
    def view_id(self):
        """Get the view_id of this Cell.

        The reference to a view from the views API.

        :return: The view_id of this Cell.
        :rtype: str
        """  # noqa: E501
        return self._view_id

    @view_id.setter
    def view_id(self, view_id):
        """Set the view_id of this Cell.

        The reference to a view from the views API.

        :param view_id: The view_id of this Cell.
        :type: str
        """  # noqa: E501
        self._view_id = view_id

    def to_dict(self):
        """Return the model properties as a dict."""
        result = {}

        for attr, _ in self.openapi_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Return the string representation of the model."""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`."""
        return self.to_str()

    def __eq__(self, other):
        """Return true if both objects are equal."""
        if not isinstance(other, Cell):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Return true if both objects are not equal."""
        return not self == other



# coding: utf-8

"""
InfluxDB OSS API Service.

The InfluxDB v2 API provides a programmatic interface for all interactions with InfluxDB. Access the InfluxDB API using the `/api/v2/` endpoint.   # noqa: E501

OpenAPI spec version: 2.0.0
Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

from influxdb_client.service._base_service import _BaseService


class WriteService(_BaseService):
    """NOTE: This class is auto generated by OpenAPI Generator.

    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):  # noqa: E501,D401,D403
        """WriteService - a operation defined in OpenAPI."""
        super().__init__(api_client)

    def post_write(self, org, bucket, body, **kwargs):  # noqa: E501,D401,D403
        """Write data.

        Writes data to a bucket.  Use this endpoint to send data in [line protocol](https://docs.influxdata.com/influxdb/latest/reference/syntax/line-protocol/) format to InfluxDB.  #### InfluxDB Cloud  - Does the following when you send a write request:    1. Validates the request and queues the write.   2. If queued, responds with _success_ (HTTP `2xx` status code); _error_ otherwise.   3. Handles the delete asynchronously and reaches eventual consistency.    To ensure that InfluxDB Cloud handles writes and deletes in the order you request them,   wait for a success response (HTTP `2xx` status code) before you send the next request.    Because writes and deletes are asynchronous, your change might not yet be readable   when you receive the response.  #### InfluxDB OSS  - Validates the request and handles the write synchronously. - If all points were written successfully, responds with HTTP `2xx` status code;   otherwise, returns the first line that failed.  #### Required permissions  - `write-buckets` or `write-bucket BUCKET_ID`.   *`BUCKET_ID`* is the ID of the destination bucket.  #### Rate limits (with InfluxDB Cloud)  `write` rate limits apply. For more information, see [limits and adjustable quotas](https://docs.influxdata.com/influxdb/cloud/account-management/limits/).  #### Related guides  - [Write data with the InfluxDB API](https://docs.influxdata.com/influxdb/latest/write-data/developer-tools/api) - [Optimize writes to InfluxDB](https://docs.influxdata.com/influxdb/latest/write-data/best-practices/optimize-writes/) - [Troubleshoot issues writing data](https://docs.influxdata.com/influxdb/latest/write-data/troubleshoot/)
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_write(org, bucket, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org: An organization name or ID.  #### InfluxDB Cloud  - Doesn't use the `org` parameter or `orgID` parameter. - Writes data to the bucket in the organization   associated with the authorization (API token).  #### InfluxDB OSS  - Requires either the `org` parameter or the `orgID` parameter. - If you pass both `orgID` and `org`, they must both be valid. - Writes data to the bucket in the specified organization. (required)
        :param str bucket: A bucket name or ID. InfluxDB writes all points in the batch to the specified bucket. (required)
        :param str body: In the request body, provide data in [line protocol format](https://docs.influxdata.com/influxdb/latest/reference/syntax/line-protocol/).  To send compressed data, do the following:    1. Use [GZIP](https://www.gzip.org/) to compress the line protocol data.   2. In your request, send the compressed data and the      `Content-Encoding: gzip` header.  #### Related guides  - [Best practices for optimizing writes](https://docs.influxdata.com/influxdb/latest/write-data/best-practices/optimize-writes/)  (required)
        :param str zap_trace_span: OpenTracing span context
        :param str content_encoding: The compression applied to the line protocol in the request payload. To send a GZIP payload, pass `Content-Encoding: gzip` header.
        :param str content_type: The format of the data in the request body. To send a line protocol payload, pass `Content-Type: text/plain; charset=utf-8`.
        :param int content_length: The size of the entity-body, in bytes, sent to InfluxDB. If the length is greater than the `max body` configuration option, the server responds with status code `413`.
        :param str accept: The content type that the client can understand. Writes only return a response body if they fail--for example, due to a formatting problem or quota limit.  #### InfluxDB Cloud    - Returns only `application/json` for format and limit errors.   - Returns only `text/html` for some quota limit errors.  #### InfluxDB OSS    - Returns only `application/json` for format and limit errors.  #### Related guides  - [Troubleshoot issues writing data](https://docs.influxdata.com/influxdb/latest/write-data/troubleshoot/)
        :param str org_id: An organization ID.  #### InfluxDB Cloud  - Doesn't use the `org` parameter or `orgID` parameter. - Writes data to the bucket in the organization   associated with the authorization (API token).  #### InfluxDB OSS  - Requires either the `org` parameter or the `orgID` parameter. - If you pass both `orgID` and `org`, they must both be valid. - Writes data to the bucket in the specified organization.
        :param WritePrecision precision: The precision for unix timestamps in the line protocol batch.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_write_with_http_info(org, bucket, body, **kwargs)  # noqa: E501
        else:
            (data) = self.post_write_with_http_info(org, bucket, body, **kwargs)  # noqa: E501
            return data

    def post_write_with_http_info(self, org, bucket, body, **kwargs):  # noqa: E501,D401,D403
        """Write data.

        Writes data to a bucket.  Use this endpoint to send data in [line protocol](https://docs.influxdata.com/influxdb/latest/reference/syntax/line-protocol/) format to InfluxDB.  #### InfluxDB Cloud  - Does the following when you send a write request:    1. Validates the request and queues the write.   2. If queued, responds with _success_ (HTTP `2xx` status code); _error_ otherwise.   3. Handles the delete asynchronously and reaches eventual consistency.    To ensure that InfluxDB Cloud handles writes and deletes in the order you request them,   wait for a success response (HTTP `2xx` status code) before you send the next request.    Because writes and deletes are asynchronous, your change might not yet be readable   when you receive the response.  #### InfluxDB OSS  - Validates the request and handles the write synchronously. - If all points were written successfully, responds with HTTP `2xx` status code;   otherwise, returns the first line that failed.  #### Required permissions  - `write-buckets` or `write-bucket BUCKET_ID`.   *`BUCKET_ID`* is the ID of the destination bucket.  #### Rate limits (with InfluxDB Cloud)  `write` rate limits apply. For more information, see [limits and adjustable quotas](https://docs.influxdata.com/influxdb/cloud/account-management/limits/).  #### Related guides  - [Write data with the InfluxDB API](https://docs.influxdata.com/influxdb/latest/write-data/developer-tools/api) - [Optimize writes to InfluxDB](https://docs.influxdata.com/influxdb/latest/write-data/best-practices/optimize-writes/) - [Troubleshoot issues writing data](https://docs.influxdata.com/influxdb/latest/write-data/troubleshoot/)
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_write_with_http_info(org, bucket, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org: An organization name or ID.  #### InfluxDB Cloud  - Doesn't use the `org` parameter or `orgID` parameter. - Writes data to the bucket in the organization   associated with the authorization (API token).  #### InfluxDB OSS  - Requires either the `org` parameter or the `orgID` parameter. - If you pass both `orgID` and `org`, they must both be valid. - Writes data to the bucket in the specified organization. (required)
        :param str bucket: A bucket name or ID. InfluxDB writes all points in the batch to the specified bucket. (required)
        :param str body: In the request body, provide data in [line protocol format](https://docs.influxdata.com/influxdb/latest/reference/syntax/line-protocol/).  To send compressed data, do the following:    1. Use [GZIP](https://www.gzip.org/) to compress the line protocol data.   2. In your request, send the compressed data and the      `Content-Encoding: gzip` header.  #### Related guides  - [Best practices for optimizing writes](https://docs.influxdata.com/influxdb/latest/write-data/best-practices/optimize-writes/)  (required)
        :param str zap_trace_span: OpenTracing span context
        :param str content_encoding: The compression applied to the line protocol in the request payload. To send a GZIP payload, pass `Content-Encoding: gzip` header.
        :param str content_type: The format of the data in the request body. To send a line protocol payload, pass `Content-Type: text/plain; charset=utf-8`.
        :param int content_length: The size of the entity-body, in bytes, sent to InfluxDB. If the length is greater than the `max body` configuration option, the server responds with status code `413`.
        :param str accept: The content type that the client can understand. Writes only return a response body if they fail--for example, due to a formatting problem or quota limit.  #### InfluxDB Cloud    - Returns only `application/json` for format and limit errors.   - Returns only `text/html` for some quota limit errors.  #### InfluxDB OSS    - Returns only `application/json` for format and limit errors.  #### Related guides  - [Troubleshoot issues writing data](https://docs.influxdata.com/influxdb/latest/write-data/troubleshoot/)
        :param str org_id: An organization ID.  #### InfluxDB Cloud  - Doesn't use the `org` parameter or `orgID` parameter. - Writes data to the bucket in the organization   associated with the authorization (API token).  #### InfluxDB OSS  - Requires either the `org` parameter or the `orgID` parameter. - If you pass both `orgID` and `org`, they must both be valid. - Writes data to the bucket in the specified organization.
        :param WritePrecision precision: The precision for unix timestamps in the line protocol batch.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._post_write_prepare(org, bucket, body, **kwargs)  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/write', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type=None,  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    async def post_write_async(self, org, bucket, body, **kwargs):  # noqa: E501,D401,D403
        """Write data.

        Writes data to a bucket.  Use this endpoint to send data in [line protocol](https://docs.influxdata.com/influxdb/latest/reference/syntax/line-protocol/) format to InfluxDB.  #### InfluxDB Cloud  - Does the following when you send a write request:    1. Validates the request and queues the write.   2. If queued, responds with _success_ (HTTP `2xx` status code); _error_ otherwise.   3. Handles the delete asynchronously and reaches eventual consistency.    To ensure that InfluxDB Cloud handles writes and deletes in the order you request them,   wait for a success response (HTTP `2xx` status code) before you send the next request.    Because writes and deletes are asynchronous, your change might not yet be readable   when you receive the response.  #### InfluxDB OSS  - Validates the request and handles the write synchronously. - If all points were written successfully, responds with HTTP `2xx` status code;   otherwise, returns the first line that failed.  #### Required permissions  - `write-buckets` or `write-bucket BUCKET_ID`.   *`BUCKET_ID`* is the ID of the destination bucket.  #### Rate limits (with InfluxDB Cloud)  `write` rate limits apply. For more information, see [limits and adjustable quotas](https://docs.influxdata.com/influxdb/cloud/account-management/limits/).  #### Related guides  - [Write data with the InfluxDB API](https://docs.influxdata.com/influxdb/latest/write-data/developer-tools/api) - [Optimize writes to InfluxDB](https://docs.influxdata.com/influxdb/latest/write-data/best-practices/optimize-writes/) - [Troubleshoot issues writing data](https://docs.influxdata.com/influxdb/latest/write-data/troubleshoot/)
        This method makes an asynchronous HTTP request.

        :param async_req bool
        :param str org: An organization name or ID.  #### InfluxDB Cloud  - Doesn't use the `org` parameter or `orgID` parameter. - Writes data to the bucket in the organization   associated with the authorization (API token).  #### InfluxDB OSS  - Requires either the `org` parameter or the `orgID` parameter. - If you pass both `orgID` and `org`, they must both be valid. - Writes data to the bucket in the specified organization. (required)
        :param str bucket: A bucket name or ID. InfluxDB writes all points in the batch to the specified bucket. (required)
        :param str body: In the request body, provide data in [line protocol format](https://docs.influxdata.com/influxdb/latest/reference/syntax/line-protocol/).  To send compressed data, do the following:    1. Use [GZIP](https://www.gzip.org/) to compress the line protocol data.   2. In your request, send the compressed data and the      `Content-Encoding: gzip` header.  #### Related guides  - [Best practices for optimizing writes](https://docs.influxdata.com/influxdb/latest/write-data/best-practices/optimize-writes/)  (required)
        :param str zap_trace_span: OpenTracing span context
        :param str content_encoding: The compression applied to the line protocol in the request payload. To send a GZIP payload, pass `Content-Encoding: gzip` header.
        :param str content_type: The format of the data in the request body. To send a line protocol payload, pass `Content-Type: text/plain; charset=utf-8`.
        :param int content_length: The size of the entity-body, in bytes, sent to InfluxDB. If the length is greater than the `max body` configuration option, the server responds with status code `413`.
        :param str accept: The content type that the client can understand. Writes only return a response body if they fail--for example, due to a formatting problem or quota limit.  #### InfluxDB Cloud    - Returns only `application/json` for format and limit errors.   - Returns only `text/html` for some quota limit errors.  #### InfluxDB OSS    - Returns only `application/json` for format and limit errors.  #### Related guides  - [Troubleshoot issues writing data](https://docs.influxdata.com/influxdb/latest/write-data/troubleshoot/)
        :param str org_id: An organization ID.  #### InfluxDB Cloud  - Doesn't use the `org` parameter or `orgID` parameter. - Writes data to the bucket in the organization   associated with the authorization (API token).  #### InfluxDB OSS  - Requires either the `org` parameter or the `orgID` parameter. - If you pass both `orgID` and `org`, they must both be valid. - Writes data to the bucket in the specified organization.
        :param WritePrecision precision: The precision for unix timestamps in the line protocol batch.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._post_write_prepare(org, bucket, body, **kwargs)  # noqa: E501

        return await self.api_client.call_api(
            '/api/v2/write', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type=None,  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    def _post_write_prepare(self, org, bucket, body, **kwargs):  # noqa: E501,D401,D403
        local_var_params = locals()

        all_params = ['org', 'bucket', 'body', 'zap_trace_span', 'content_encoding', 'content_type', 'content_length', 'accept', 'org_id', 'precision']  # noqa: E501
        self._check_operation_params('post_write', all_params, local_var_params)
        # verify the required parameter 'org' is set
        if ('org' not in local_var_params or
                local_var_params['org'] is None):
            raise ValueError("Missing the required parameter `org` when calling `post_write`")  # noqa: E501
        # verify the required parameter 'bucket' is set
        if ('bucket' not in local_var_params or
                local_var_params['bucket'] is None):
            raise ValueError("Missing the required parameter `bucket` when calling `post_write`")  # noqa: E501
        # verify the required parameter 'body' is set
        if ('body' not in local_var_params or
                local_var_params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_write`")  # noqa: E501

        path_params = {}

        query_params = []
        if 'org' in local_var_params:
            query_params.append(('org', local_var_params['org']))  # noqa: E501
        if 'org_id' in local_var_params:
            query_params.append(('orgID', local_var_params['org_id']))  # noqa: E501
        if 'bucket' in local_var_params:
            query_params.append(('bucket', local_var_params['bucket']))  # noqa: E501
        if 'precision' in local_var_params:
            query_params.append(('precision', local_var_params['precision']))  # noqa: E501

        header_params = {}
        if 'zap_trace_span' in local_var_params:
            header_params['Zap-Trace-Span'] = local_var_params['zap_trace_span']  # noqa: E501
        if 'content_encoding' in local_var_params:
            header_params['Content-Encoding'] = local_var_params['content_encoding']  # noqa: E501
        if 'content_type' in local_var_params:
            header_params['Content-Type'] = local_var_params['content_type']  # noqa: E501
        if 'content_length' in local_var_params:
            header_params['Content-Length'] = local_var_params['content_length']  # noqa: E501
        if 'accept' in local_var_params:
            header_params['Accept'] = local_var_params['accept']  # noqa: E501

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/html', ])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/plain'])  # noqa: E501

        return local_var_params, path_params, query_params, header_params, body_params



# coding: utf-8

"""
InfluxDB OSS API Service.

The InfluxDB v2 API provides a programmatic interface for all interactions with InfluxDB. Access the InfluxDB API using the `/api/v2/` endpoint.   # noqa: E501

OpenAPI spec version: 2.0.0
Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401


class BuilderTagsType(object):
    """NOTE: This class is auto generated by OpenAPI Generator.

    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'key': 'str',
        'values': 'list[str]',
        'aggregate_function_type': 'BuilderAggregateFunctionType'
    }

    attribute_map = {
        'key': 'key',
        'values': 'values',
        'aggregate_function_type': 'aggregateFunctionType'
    }

    def __init__(self, key=None, values=None, aggregate_function_type=None):  # noqa: E501,D401,D403
        """BuilderTagsType - a model defined in OpenAPI."""  # noqa: E501
        self._key = None
        self._values = None
        self._aggregate_function_type = None
        self.discriminator = None

        if key is not None:
            self.key = key
        if values is not None:
            self.values = values
        if aggregate_function_type is not None:
            self.aggregate_function_type = aggregate_function_type

    @property
    def key(self):
        """Get the key of this BuilderTagsType.

        :return: The key of this BuilderTagsType.
        :rtype: str
        """  # noqa: E501
        return self._key

    @key.setter
    def key(self, key):
        """Set the key of this BuilderTagsType.

        :param key: The key of this BuilderTagsType.
        :type: str
        """  # noqa: E501
        self._key = key

    @property
    def values(self):
        """Get the values of this BuilderTagsType.

        :return: The values of this BuilderTagsType.
        :rtype: list[str]
        """  # noqa: E501
        return self._values

    @values.setter
    def values(self, values):
        """Set the values of this BuilderTagsType.

        :param values: The values of this BuilderTagsType.
        :type: list[str]
        """  # noqa: E501
        self._values = values

    @property
    def aggregate_function_type(self):
        """Get the aggregate_function_type of this BuilderTagsType.

        :return: The aggregate_function_type of this BuilderTagsType.
        :rtype: BuilderAggregateFunctionType
        """  # noqa: E501
        return self._aggregate_function_type

    @aggregate_function_type.setter
    def aggregate_function_type(self, aggregate_function_type):
        """Set the aggregate_function_type of this BuilderTagsType.

        :param aggregate_function_type: The aggregate_function_type of this BuilderTagsType.
        :type: BuilderAggregateFunctionType
        """  # noqa: E501
        self._aggregate_function_type = aggregate_function_type

    def to_dict(self):
        """Return the model properties as a dict."""
        result = {}

        for attr, _ in self.openapi_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Return the string representation of the model."""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`."""
        return self.to_str()

    def __eq__(self, other):
        """Return true if both objects are equal."""
        if not isinstance(other, BuilderTagsType):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Return true if both objects are not equal."""
        return not self == other



# coding: utf-8

"""
InfluxDB OSS API Service.

The InfluxDB v2 API provides a programmatic interface for all interactions with InfluxDB. Access the InfluxDB API using the `/api/v2/` endpoint.   # noqa: E501

OpenAPI spec version: 2.0.0
Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

from influxdb_client.domain.view_properties import ViewProperties


class HeatmapViewProperties(ViewProperties):
    """NOTE: This class is auto generated by OpenAPI Generator.

    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'adaptive_zoom_hide': 'bool',
        'time_format': 'str',
        'type': 'str',
        'queries': 'list[DashboardQuery]',
        'colors': 'list[str]',
        'shape': 'str',
        'note': 'str',
        'show_note_when_empty': 'bool',
        'x_column': 'str',
        'generate_x_axis_ticks': 'list[str]',
        'x_total_ticks': 'int',
        'x_tick_start': 'float',
        'x_tick_step': 'float',
        'y_column': 'str',
        'generate_y_axis_ticks': 'list[str]',
        'y_total_ticks': 'int',
        'y_tick_start': 'float',
        'y_tick_step': 'float',
        'x_domain': 'list[float]',
        'y_domain': 'list[float]',
        'x_axis_label': 'str',
        'y_axis_label': 'str',
        'x_prefix': 'str',
        'x_suffix': 'str',
        'y_prefix': 'str',
        'y_suffix': 'str',
        'bin_size': 'float',
        'legend_colorize_rows': 'bool',
        'legend_hide': 'bool',
        'legend_opacity': 'float',
        'legend_orientation_threshold': 'int'
    }

    attribute_map = {
        'adaptive_zoom_hide': 'adaptiveZoomHide',
        'time_format': 'timeFormat',
        'type': 'type',
        'queries': 'queries',
        'colors': 'colors',
        'shape': 'shape',
        'note': 'note',
        'show_note_when_empty': 'showNoteWhenEmpty',
        'x_column': 'xColumn',
        'generate_x_axis_ticks': 'generateXAxisTicks',
        'x_total_ticks': 'xTotalTicks',
        'x_tick_start': 'xTickStart',
        'x_tick_step': 'xTickStep',
        'y_column': 'yColumn',
        'generate_y_axis_ticks': 'generateYAxisTicks',
        'y_total_ticks': 'yTotalTicks',
        'y_tick_start': 'yTickStart',
        'y_tick_step': 'yTickStep',
        'x_domain': 'xDomain',
        'y_domain': 'yDomain',
        'x_axis_label': 'xAxisLabel',
        'y_axis_label': 'yAxisLabel',
        'x_prefix': 'xPrefix',
        'x_suffix': 'xSuffix',
        'y_prefix': 'yPrefix',
        'y_suffix': 'ySuffix',
        'bin_size': 'binSize',
        'legend_colorize_rows': 'legendColorizeRows',
        'legend_hide': 'legendHide',
        'legend_opacity': 'legendOpacity',
        'legend_orientation_threshold': 'legendOrientationThreshold'
    }

    def __init__(self, adaptive_zoom_hide=None, time_format=None, type=None, queries=None, colors=None, shape=None, note=None, show_note_when_empty=None, x_column=None, generate_x_axis_ticks=None, x_total_ticks=None, x_tick_start=None, x_tick_step=None, y_column=None, generate_y_axis_ticks=None, y_total_ticks=None, y_tick_start=None, y_tick_step=None, x_domain=None, y_domain=None, x_axis_label=None, y_axis_label=None, x_prefix=None, x_suffix=None, y_prefix=None, y_suffix=None, bin_size=None, legend_colorize_rows=None, legend_hide=None, legend_opacity=None, legend_orientation_threshold=None):  # noqa: E501,D401,D403
        """HeatmapViewProperties - a model defined in OpenAPI."""  # noqa: E501
        ViewProperties.__init__(self)  # noqa: E501

        self._adaptive_zoom_hide = None
        self._time_format = None
        self._type = None
        self._queries = None
        self._colors = None
        self._shape = None
        self._note = None
        self._show_note_when_empty = None
        self._x_column = None
        self._generate_x_axis_ticks = None
        self._x_total_ticks = None
        self._x_tick_start = None
        self._x_tick_step = None
        self._y_column = None
        self._generate_y_axis_ticks = None
        self._y_total_ticks = None
        self._y_tick_start = None
        self._y_tick_step = None
        self._x_domain = None
        self._y_domain = None
        self._x_axis_label = None
        self._y_axis_label = None
        self._x_prefix = None
        self._x_suffix = None
        self._y_prefix = None
        self._y_suffix = None
        self._bin_size = None
        self._legend_colorize_rows = None
        self._legend_hide = None
        self._legend_opacity = None
        self._legend_orientation_threshold = None
        self.discriminator = None

        if adaptive_zoom_hide is not None:
            self.adaptive_zoom_hide = adaptive_zoom_hide
        if time_format is not None:
            self.time_format = time_format
        self.type = type
        self.queries = queries
        self.colors = colors
        self.shape = shape
        self.note = note
        self.show_note_when_empty = show_note_when_empty
        self.x_column = x_column
        if generate_x_axis_ticks is not None:
            self.generate_x_axis_ticks = generate_x_axis_ticks
        if x_total_ticks is not None:
            self.x_total_ticks = x_total_ticks
        if x_tick_start is not None:
            self.x_tick_start = x_tick_start
        if x_tick_step is not None:
            self.x_tick_step = x_tick_step
        self.y_column = y_column
        if generate_y_axis_ticks is not None:
            self.generate_y_axis_ticks = generate_y_axis_ticks
        if y_total_ticks is not None:
            self.y_total_ticks = y_total_ticks
        if y_tick_start is not None:
            self.y_tick_start = y_tick_start
        if y_tick_step is not None:
            self.y_tick_step = y_tick_step
        self.x_domain = x_domain
        self.y_domain = y_domain
        self.x_axis_label = x_axis_label
        self.y_axis_label = y_axis_label
        self.x_prefix = x_prefix
        self.x_suffix = x_suffix
        self.y_prefix = y_prefix
        self.y_suffix = y_suffix
        self.bin_size = bin_size
        if legend_colorize_rows is not None:
            self.legend_colorize_rows = legend_colorize_rows
        if legend_hide is not None:
            self.legend_hide = legend_hide
        if legend_opacity is not None:
            self.legend_opacity = legend_opacity
        if legend_orientation_threshold is not None:
            self.legend_orientation_threshold = legend_orientation_threshold

    @property
    def adaptive_zoom_hide(self):
        """Get the adaptive_zoom_hide of this HeatmapViewProperties.

        :return: The adaptive_zoom_hide of this HeatmapViewProperties.
        :rtype: bool
        """  # noqa: E501
        return self._adaptive_zoom_hide

    @adaptive_zoom_hide.setter
    def adaptive_zoom_hide(self, adaptive_zoom_hide):
        """Set the adaptive_zoom_hide of this HeatmapViewProperties.

        :param adaptive_zoom_hide: The adaptive_zoom_hide of this HeatmapViewProperties.
        :type: bool
        """  # noqa: E501
        self._adaptive_zoom_hide = adaptive_zoom_hide

    @property
    def time_format(self):
        """Get the time_format of this HeatmapViewProperties.

        :return: The time_format of this HeatmapViewProperties.
        :rtype: str
        """  # noqa: E501
        return self._time_format

    @time_format.setter
    def time_format(self, time_format):
        """Set the time_format of this HeatmapViewProperties.

        :param time_format: The time_format of this HeatmapViewProperties.
        :type: str
        """  # noqa: E501
        self._time_format = time_format

    @property
    def type(self):
        """Get the type of this HeatmapViewProperties.

        :return: The type of this HeatmapViewProperties.
        :rtype: str
        """  # noqa: E501
        return self._type

    @type.setter
    def type(self, type):
        """Set the type of this HeatmapViewProperties.

        :param type: The type of this HeatmapViewProperties.
        :type: str
        """  # noqa: E501
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        self._type = type

    @property
    def queries(self):
        """Get the queries of this HeatmapViewProperties.

        :return: The queries of this HeatmapViewProperties.
        :rtype: list[DashboardQuery]
        """  # noqa: E501
        return self._queries

    @queries.setter
    def queries(self, queries):
        """Set the queries of this HeatmapViewProperties.

        :param queries: The queries of this HeatmapViewProperties.
        :type: list[DashboardQuery]
        """  # noqa: E501
        if queries is None:
            raise ValueError("Invalid value for `queries`, must not be `None`")  # noqa: E501
        self._queries = queries

    @property
    def colors(self):
        """Get the colors of this HeatmapViewProperties.

        Colors define color encoding of data into a visualization

        :return: The colors of this HeatmapViewProperties.
        :rtype: list[str]
        """  # noqa: E501
        return self._colors

    @colors.setter
    def colors(self, colors):
        """Set the colors of this HeatmapViewProperties.

        Colors define color encoding of data into a visualization

        :param colors: The colors of this HeatmapViewProperties.
        :type: list[str]
        """  # noqa: E501
        if colors is None:
            raise ValueError("Invalid value for `colors`, must not be `None`")  # noqa: E501
        self._colors = colors

    @property
    def shape(self):
        """Get the shape of this HeatmapViewProperties.

        :return: The shape of this HeatmapViewProperties.
        :rtype: str
        """  # noqa: E501
        return self._shape

    @shape.setter
    def shape(self, shape):
        """Set the shape of this HeatmapViewProperties.

        :param shape: The shape of this HeatmapViewProperties.
        :type: str
        """  # noqa: E501
        if shape is None:
            raise ValueError("Invalid value for `shape`, must not be `None`")  # noqa: E501
        self._shape = shape

    @property
    def note(self):
        """Get the note of this HeatmapViewProperties.

        :return: The note of this HeatmapViewProperties.
        :rtype: str
        """  # noqa: E501
        return self._note

    @note.setter
    def note(self, note):
        """Set the note of this HeatmapViewProperties.

        :param note: The note of this HeatmapViewProperties.
        :type: str
        """  # noqa: E501
        if note is None:
            raise ValueError("Invalid value for `note`, must not be `None`")  # noqa: E501
        self._note = note

    @property
    def show_note_when_empty(self):
        """Get the show_note_when_empty of this HeatmapViewProperties.

        If true, will display note when empty

        :return: The show_note_when_empty of this HeatmapViewProperties.
        :rtype: bool
        """  # noqa: E501
        return self._show_note_when_empty

    @show_note_when_empty.setter
    def show_note_when_empty(self, show_note_when_empty):
        """Set the show_note_when_empty of this HeatmapViewProperties.

        If true, will display note when empty

        :param show_note_when_empty: The show_note_when_empty of this HeatmapViewProperties.
        :type: bool
        """  # noqa: E501
        if show_note_when_empty is None:
            raise ValueError("Invalid value for `show_note_when_empty`, must not be `None`")  # noqa: E501
        self._show_note_when_empty = show_note_when_empty

    @property
    def x_column(self):
        """Get the x_column of this HeatmapViewProperties.

        :return: The x_column of this HeatmapViewProperties.
        :rtype: str
        """  # noqa: E501
        return self._x_column

    @x_column.setter
    def x_column(self, x_column):
        """Set the x_column of this HeatmapViewProperties.

        :param x_column: The x_column of this HeatmapViewProperties.
        :type: str
        """  # noqa: E501
        if x_column is None:
            raise ValueError("Invalid value for `x_column`, must not be `None`")  # noqa: E501
        self._x_column = x_column

    @property
    def generate_x_axis_ticks(self):
        """Get the generate_x_axis_ticks of this HeatmapViewProperties.

        :return: The generate_x_axis_ticks of this HeatmapViewProperties.
        :rtype: list[str]
        """  # noqa: E501
        return self._generate_x_axis_ticks

    @generate_x_axis_ticks.setter
    def generate_x_axis_ticks(self, generate_x_axis_ticks):
        """Set the generate_x_axis_ticks of this HeatmapViewProperties.

        :param generate_x_axis_ticks: The generate_x_axis_ticks of this HeatmapViewProperties.
        :type: list[str]
        """  # noqa: E501
        self._generate_x_axis_ticks = generate_x_axis_ticks

    @property
    def x_total_ticks(self):
        """Get the x_total_ticks of this HeatmapViewProperties.

        :return: The x_total_ticks of this HeatmapViewProperties.
        :rtype: int
        """  # noqa: E501
        return self._x_total_ticks

    @x_total_ticks.setter
    def x_total_ticks(self, x_total_ticks):
        """Set the x_total_ticks of this HeatmapViewProperties.

        :param x_total_ticks: The x_total_ticks of this HeatmapViewProperties.
        :type: int
        """  # noqa: E501
        self._x_total_ticks = x_total_ticks

    @property
    def x_tick_start(self):
        """Get the x_tick_start of this HeatmapViewProperties.

        :return: The x_tick_start of this HeatmapViewProperties.
        :rtype: float
        """  # noqa: E501
        return self._x_tick_start

    @x_tick_start.setter
    def x_tick_start(self, x_tick_start):
        """Set the x_tick_start of this HeatmapViewProperties.

        :param x_tick_start: The x_tick_start of this HeatmapViewProperties.
        :type: float
        """  # noqa: E501
        self._x_tick_start = x_tick_start

    @property
    def x_tick_step(self):
        """Get the x_tick_step of this HeatmapViewProperties.

        :return: The x_tick_step of this HeatmapViewProperties.
        :rtype: float
        """  # noqa: E501
        return self._x_tick_step

    @x_tick_step.setter
    def x_tick_step(self, x_tick_step):
        """Set the x_tick_step of this HeatmapViewProperties.

        :param x_tick_step: The x_tick_step of this HeatmapViewProperties.
        :type: float
        """  # noqa: E501
        self._x_tick_step = x_tick_step

    @property
    def y_column(self):
        """Get the y_column of this HeatmapViewProperties.

        :return: The y_column of this HeatmapViewProperties.
        :rtype: str
        """  # noqa: E501
        return self._y_column

    @y_column.setter
    def y_column(self, y_column):
        """Set the y_column of this HeatmapViewProperties.

        :param y_column: The y_column of this HeatmapViewProperties.
        :type: str
        """  # noqa: E501
        if y_column is None:
            raise ValueError("Invalid value for `y_column`, must not be `None`")  # noqa: E501
        self._y_column = y_column

    @property
    def generate_y_axis_ticks(self):
        """Get the generate_y_axis_ticks of this HeatmapViewProperties.

        :return: The generate_y_axis_ticks of this HeatmapViewProperties.
        :rtype: list[str]
        """  # noqa: E501
        return self._generate_y_axis_ticks

    @generate_y_axis_ticks.setter
    def generate_y_axis_ticks(self, generate_y_axis_ticks):
        """Set the generate_y_axis_ticks of this HeatmapViewProperties.

        :param generate_y_axis_ticks: The generate_y_axis_ticks of this HeatmapViewProperties.
        :type: list[str]
        """  # noqa: E501
        self._generate_y_axis_ticks = generate_y_axis_ticks

    @property
    def y_total_ticks(self):
        """Get the y_total_ticks of this HeatmapViewProperties.

        :return: The y_total_ticks of this HeatmapViewProperties.
        :rtype: int
        """  # noqa: E501
        return self._y_total_ticks

    @y_total_ticks.setter
    def y_total_ticks(self, y_total_ticks):
        """Set the y_total_ticks of this HeatmapViewProperties.

        :param y_total_ticks: The y_total_ticks of this HeatmapViewProperties.
        :type: int
        """  # noqa: E501
        self._y_total_ticks = y_total_ticks

    @property
    def y_tick_start(self):
        """Get the y_tick_start of this HeatmapViewProperties.

        :return: The y_tick_start of this HeatmapViewProperties.
        :rtype: float
        """  # noqa: E501
        return self._y_tick_start

    @y_tick_start.setter
    def y_tick_start(self, y_tick_start):
        """Set the y_tick_start of this HeatmapViewProperties.

        :param y_tick_start: The y_tick_start of this HeatmapViewProperties.
        :type: float
        """  # noqa: E501
        self._y_tick_start = y_tick_start

    @property
    def y_tick_step(self):
        """Get the y_tick_step of this HeatmapViewProperties.

        :return: The y_tick_step of this HeatmapViewProperties.
        :rtype: float
        """  # noqa: E501
        return self._y_tick_step

    @y_tick_step.setter
    def y_tick_step(self, y_tick_step):
        """Set the y_tick_step of this HeatmapViewProperties.

        :param y_tick_step: The y_tick_step of this HeatmapViewProperties.
        :type: float
        """  # noqa: E501
        self._y_tick_step = y_tick_step

    @property
    def x_domain(self):
        """Get the x_domain of this HeatmapViewProperties.

        :return: The x_domain of this HeatmapViewProperties.
        :rtype: list[float]
        """  # noqa: E501
        return self._x_domain

    @x_domain.setter
    def x_domain(self, x_domain):
        """Set the x_domain of this HeatmapViewProperties.

        :param x_domain: The x_domain of this HeatmapViewProperties.
        :type: list[float]
        """  # noqa: E501
        if x_domain is None:
            raise ValueError("Invalid value for `x_domain`, must not be `None`")  # noqa: E501
        self._x_domain = x_domain

    @property
    def y_domain(self):
        """Get the y_domain of this HeatmapViewProperties.

        :return: The y_domain of this HeatmapViewProperties.
        :rtype: list[float]
        """  # noqa: E501
        return self._y_domain

    @y_domain.setter
    def y_domain(self, y_domain):
        """Set the y_domain of this HeatmapViewProperties.

        :param y_domain: The y_domain of this HeatmapViewProperties.
        :type: list[float]
        """  # noqa: E501
        if y_domain is None:
            raise ValueError("Invalid value for `y_domain`, must not be `None`")  # noqa: E501
        self._y_domain = y_domain

    @property
    def x_axis_label(self):
        """Get the x_axis_label of this HeatmapViewProperties.

        :return: The x_axis_label of this HeatmapViewProperties.
        :rtype: str
        """  # noqa: E501
        return self._x_axis_label

    @x_axis_label.setter
    def x_axis_label(self, x_axis_label):
        """Set the x_axis_label of this HeatmapViewProperties.

        :param x_axis_label: The x_axis_label of this HeatmapViewProperties.
        :type: str
        """  # noqa: E501
        if x_axis_label is None:
            raise ValueError("Invalid value for `x_axis_label`, must not be `None`")  # noqa: E501
        self._x_axis_label = x_axis_label

    @property
    def y_axis_label(self):
        """Get the y_axis_label of this HeatmapViewProperties.

        :return: The y_axis_label of this HeatmapViewProperties.
        :rtype: str
        """  # noqa: E501
        return self._y_axis_label

    @y_axis_label.setter
    def y_axis_label(self, y_axis_label):
        """Set the y_axis_label of this HeatmapViewProperties.

        :param y_axis_label: The y_axis_label of this HeatmapViewProperties.
        :type: str
        """  # noqa: E501
        if y_axis_label is None:
            raise ValueError("Invalid value for `y_axis_label`, must not be `None`")  # noqa: E501
        self._y_axis_label = y_axis_label

    @property
    def x_prefix(self):
        """Get the x_prefix of this HeatmapViewProperties.

        :return: The x_prefix of this HeatmapViewProperties.
        :rtype: str
        """  # noqa: E501
        return self._x_prefix

    @x_prefix.setter
    def x_prefix(self, x_prefix):
        """Set the x_prefix of this HeatmapViewProperties.

        :param x_prefix: The x_prefix of this HeatmapViewProperties.
        :type: str
        """  # noqa: E501
        if x_prefix is None:
            raise ValueError("Invalid value for `x_prefix`, must not be `None`")  # noqa: E501
        self._x_prefix = x_prefix

    @property
    def x_suffix(self):
        """Get the x_suffix of this HeatmapViewProperties.

        :return: The x_suffix of this HeatmapViewProperties.
        :rtype: str
        """  # noqa: E501
        return self._x_suffix

    @x_suffix.setter
    def x_suffix(self, x_suffix):
        """Set the x_suffix of this HeatmapViewProperties.

        :param x_suffix: The x_suffix of this HeatmapViewProperties.
        :type: str
        """  # noqa: E501
        if x_suffix is None:
            raise ValueError("Invalid value for `x_suffix`, must not be `None`")  # noqa: E501
        self._x_suffix = x_suffix

    @property
    def y_prefix(self):
        """Get the y_prefix of this HeatmapViewProperties.

        :return: The y_prefix of this HeatmapViewProperties.
        :rtype: str
        """  # noqa: E501
        return self._y_prefix

    @y_prefix.setter
    def y_prefix(self, y_prefix):
        """Set the y_prefix of this HeatmapViewProperties.

        :param y_prefix: The y_prefix of this HeatmapViewProperties.
        :type: str
        """  # noqa: E501
        if y_prefix is None:
            raise ValueError("Invalid value for `y_prefix`, must not be `None`")  # noqa: E501
        self._y_prefix = y_prefix

    @property
    def y_suffix(self):
        """Get the y_suffix of this HeatmapViewProperties.

        :return: The y_suffix of this HeatmapViewProperties.
        :rtype: str
        """  # noqa: E501
        return self._y_suffix

    @y_suffix.setter
    def y_suffix(self, y_suffix):
        """Set the y_suffix of this HeatmapViewProperties.

        :param y_suffix: The y_suffix of this HeatmapViewProperties.
        :type: str
        """  # noqa: E501
        if y_suffix is None:
            raise ValueError("Invalid value for `y_suffix`, must not be `None`")  # noqa: E501
        self._y_suffix = y_suffix

    @property
    def bin_size(self):
        """Get the bin_size of this HeatmapViewProperties.

        :return: The bin_size of this HeatmapViewProperties.
        :rtype: float
        """  # noqa: E501
        return self._bin_size

    @bin_size.setter
    def bin_size(self, bin_size):
        """Set the bin_size of this HeatmapViewProperties.

        :param bin_size: The bin_size of this HeatmapViewProperties.
        :type: float
        """  # noqa: E501
        if bin_size is None:
            raise ValueError("Invalid value for `bin_size`, must not be `None`")  # noqa: E501
        self._bin_size = bin_size

    @property
    def legend_colorize_rows(self):
        """Get the legend_colorize_rows of this HeatmapViewProperties.

        :return: The legend_colorize_rows of this HeatmapViewProperties.
        :rtype: bool
        """  # noqa: E501
        return self._legend_colorize_rows

    @legend_colorize_rows.setter
    def legend_colorize_rows(self, legend_colorize_rows):
        """Set the legend_colorize_rows of this HeatmapViewProperties.

        :param legend_colorize_rows: The legend_colorize_rows of this HeatmapViewProperties.
        :type: bool
        """  # noqa: E501
        self._legend_colorize_rows = legend_colorize_rows

    @property
    def legend_hide(self):
        """Get the legend_hide of this HeatmapViewProperties.

        :return: The legend_hide of this HeatmapViewProperties.
        :rtype: bool
        """  # noqa: E501
        return self._legend_hide

    @legend_hide.setter
    def legend_hide(self, legend_hide):
        """Set the legend_hide of this HeatmapViewProperties.

        :param legend_hide: The legend_hide of this HeatmapViewProperties.
        :type: bool
        """  # noqa: E501
        self._legend_hide = legend_hide

    @property
    def legend_opacity(self):
        """Get the legend_opacity of this HeatmapViewProperties.

        :return: The legend_opacity of this HeatmapViewProperties.
        :rtype: float
        """  # noqa: E501
        return self._legend_opacity

    @legend_opacity.setter
    def legend_opacity(self, legend_opacity):
        """Set the legend_opacity of this HeatmapViewProperties.

        :param legend_opacity: The legend_opacity of this HeatmapViewProperties.
        :type: float
        """  # noqa: E501
        self._legend_opacity = legend_opacity

    @property
    def legend_orientation_threshold(self):
        """Get the legend_orientation_threshold of this HeatmapViewProperties.

        :return: The legend_orientation_threshold of this HeatmapViewProperties.
        :rtype: int
        """  # noqa: E501
        return self._legend_orientation_threshold

    @legend_orientation_threshold.setter
    def legend_orientation_threshold(self, legend_orientation_threshold):
        """Set the legend_orientation_threshold of this HeatmapViewProperties.

        :param legend_orientation_threshold: The legend_orientation_threshold of this HeatmapViewProperties.
        :type: int
        """  # noqa: E501
        self._legend_orientation_threshold = legend_orientation_threshold

    def to_dict(self):
        """Return the model properties as a dict."""
        result = {}

        for attr, _ in self.openapi_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Return the string representation of the model."""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`."""
        return self.to_str()

    def __eq__(self, other):
        """Return true if both objects are equal."""
        if not isinstance(other, HeatmapViewProperties):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Return true if both objects are not equal."""
        return not self == other



# coding: utf-8

"""
InfluxDB OSS API Service.

The InfluxDB v2 API provides a programmatic interface for all interactions with InfluxDB. Access the InfluxDB API using the `/api/v2/` endpoint.   # noqa: E501

OpenAPI spec version: 2.0.0
Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401


class PatchRetentionRule(object):
    """NOTE: This class is auto generated by OpenAPI Generator.

    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'every_seconds': 'int',
        'shard_group_duration_seconds': 'int'
    }

    attribute_map = {
        'type': 'type',
        'every_seconds': 'everySeconds',
        'shard_group_duration_seconds': 'shardGroupDurationSeconds'
    }

    def __init__(self, type='expire', every_seconds=2592000, shard_group_duration_seconds=None):  # noqa: E501,D401,D403
        """PatchRetentionRule - a model defined in OpenAPI."""  # noqa: E501
        self._type = None
        self._every_seconds = None
        self._shard_group_duration_seconds = None
        self.discriminator = None

        if type is not None:
            self.type = type
        self.every_seconds = every_seconds
        if shard_group_duration_seconds is not None:
            self.shard_group_duration_seconds = shard_group_duration_seconds

    @property
    def type(self):
        """Get the type of this PatchRetentionRule.

        :return: The type of this PatchRetentionRule.
        :rtype: str
        """  # noqa: E501
        return self._type

    @type.setter
    def type(self, type):
        """Set the type of this PatchRetentionRule.

        :param type: The type of this PatchRetentionRule.
        :type: str
        """  # noqa: E501
        self._type = type

    @property
    def every_seconds(self):
        """Get the every_seconds of this PatchRetentionRule.

        The number of seconds to keep data. Default duration is `2592000` (30 days). `0` represents infinite retention.

        :return: The every_seconds of this PatchRetentionRule.
        :rtype: int
        """  # noqa: E501
        return self._every_seconds

    @every_seconds.setter
    def every_seconds(self, every_seconds):
        """Set the every_seconds of this PatchRetentionRule.

        The number of seconds to keep data. Default duration is `2592000` (30 days). `0` represents infinite retention.

        :param every_seconds: The every_seconds of this PatchRetentionRule.
        :type: int
        """  # noqa: E501
        if every_seconds is None:
            raise ValueError("Invalid value for `every_seconds`, must not be `None`")  # noqa: E501
        if every_seconds is not None and every_seconds < 0:  # noqa: E501
            raise ValueError("Invalid value for `every_seconds`, must be a value greater than or equal to `0`")  # noqa: E501
        self._every_seconds = every_seconds

    @property
    def shard_group_duration_seconds(self):
        """Get the shard_group_duration_seconds of this PatchRetentionRule.

        The [shard group duration](https://docs.influxdata.com/influxdb/latest/reference/glossary/#shard). The number of seconds that each shard group covers.  #### InfluxDB Cloud  - Doesn't use `shardGroupDurationsSeconds`.  #### InfluxDB OSS  - Default value depends on the [bucket retention period](https://docs.influxdata.com/influxdb/latest/reference/internals/shards/#shard-group-duration).  #### Related guides  - InfluxDB [shards and shard groups](https://docs.influxdata.com/influxdb/latest/reference/internals/shards/)

        :return: The shard_group_duration_seconds of this PatchRetentionRule.
        :rtype: int
        """  # noqa: E501
        return self._shard_group_duration_seconds

    @shard_group_duration_seconds.setter
    def shard_group_duration_seconds(self, shard_group_duration_seconds):
        """Set the shard_group_duration_seconds of this PatchRetentionRule.

        The [shard group duration](https://docs.influxdata.com/influxdb/latest/reference/glossary/#shard). The number of seconds that each shard group covers.  #### InfluxDB Cloud  - Doesn't use `shardGroupDurationsSeconds`.  #### InfluxDB OSS  - Default value depends on the [bucket retention period](https://docs.influxdata.com/influxdb/latest/reference/internals/shards/#shard-group-duration).  #### Related guides  - InfluxDB [shards and shard groups](https://docs.influxdata.com/influxdb/latest/reference/internals/shards/)

        :param shard_group_duration_seconds: The shard_group_duration_seconds of this PatchRetentionRule.
        :type: int
        """  # noqa: E501
        self._shard_group_duration_seconds = shard_group_duration_seconds

    def to_dict(self):
        """Return the model properties as a dict."""
        result = {}

        for attr, _ in self.openapi_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Return the string representation of the model."""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`."""
        return self.to_str()

    def __eq__(self, other):
        """Return true if both objects are equal."""
        if not isinstance(other, PatchRetentionRule):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Return true if both objects are not equal."""
        return not self == other



# coding: utf-8

"""
InfluxDB OSS API Service.

The InfluxDB v2 API provides a programmatic interface for all interactions with InfluxDB. Access the InfluxDB API using the `/api/v2/` endpoint.   # noqa: E501

OpenAPI spec version: 2.0.0
Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401


class TemplateChart(object):
    """NOTE: This class is auto generated by OpenAPI Generator.

    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'x_pos': 'int',
        'y_pos': 'int',
        'height': 'int',
        'width': 'int',
        'properties': 'ViewProperties'
    }

    attribute_map = {
        'x_pos': 'xPos',
        'y_pos': 'yPos',
        'height': 'height',
        'width': 'width',
        'properties': 'properties'
    }

    def __init__(self, x_pos=None, y_pos=None, height=None, width=None, properties=None):  # noqa: E501,D401,D403
        """TemplateChart - a model defined in OpenAPI."""  # noqa: E501
        self._x_pos = None
        self._y_pos = None
        self._height = None
        self._width = None
        self._properties = None
        self.discriminator = None

        if x_pos is not None:
            self.x_pos = x_pos
        if y_pos is not None:
            self.y_pos = y_pos
        if height is not None:
            self.height = height
        if width is not None:
            self.width = width
        if properties is not None:
            self.properties = properties

    @property
    def x_pos(self):
        """Get the x_pos of this TemplateChart.

        :return: The x_pos of this TemplateChart.
        :rtype: int
        """  # noqa: E501
        return self._x_pos

    @x_pos.setter
    def x_pos(self, x_pos):
        """Set the x_pos of this TemplateChart.

        :param x_pos: The x_pos of this TemplateChart.
        :type: int
        """  # noqa: E501
        self._x_pos = x_pos

    @property
    def y_pos(self):
        """Get the y_pos of this TemplateChart.

        :return: The y_pos of this TemplateChart.
        :rtype: int
        """  # noqa: E501
        return self._y_pos

    @y_pos.setter
    def y_pos(self, y_pos):
        """Set the y_pos of this TemplateChart.

        :param y_pos: The y_pos of this TemplateChart.
        :type: int
        """  # noqa: E501
        self._y_pos = y_pos

    @property
    def height(self):
        """Get the height of this TemplateChart.

        :return: The height of this TemplateChart.
        :rtype: int
        """  # noqa: E501
        return self._height

    @height.setter
    def height(self, height):
        """Set the height of this TemplateChart.

        :param height: The height of this TemplateChart.
        :type: int
        """  # noqa: E501
        self._height = height

    @property
    def width(self):
        """Get the width of this TemplateChart.

        :return: The width of this TemplateChart.
        :rtype: int
        """  # noqa: E501
        return self._width

    @width.setter
    def width(self, width):
        """Set the width of this TemplateChart.

        :param width: The width of this TemplateChart.
        :type: int
        """  # noqa: E501
        self._width = width

    @property
    def properties(self):
        """Get the properties of this TemplateChart.

        :return: The properties of this TemplateChart.
        :rtype: ViewProperties
        """  # noqa: E501
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Set the properties of this TemplateChart.

        :param properties: The properties of this TemplateChart.
        :type: ViewProperties
        """  # noqa: E501
        self._properties = properties

    def to_dict(self):
        """Return the model properties as a dict."""
        result = {}

        for attr, _ in self.openapi_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Return the string representation of the model."""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`."""
        return self.to_str()

    def __eq__(self, other):
        """Return true if both objects are equal."""
        if not isinstance(other, TemplateChart):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Return true if both objects are not equal."""
        return not self == other



# coding: utf-8

"""
InfluxDB OSS API Service.

The InfluxDB v2 API provides a programmatic interface for all interactions with InfluxDB. Access the InfluxDB API using the `/api/v2/` endpoint.   # noqa: E501

OpenAPI spec version: 2.0.0
Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

from influxdb_client.domain.authorization_update_request import AuthorizationUpdateRequest


class LegacyAuthorizationPostRequest(AuthorizationUpdateRequest):
    """NOTE: This class is auto generated by OpenAPI Generator.

    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'org_id': 'str',
        'user_id': 'str',
        'token': 'str',
        'permissions': 'list[Permission]',
        'status': 'str',
        'description': 'str'
    }

    attribute_map = {
        'org_id': 'orgID',
        'user_id': 'userID',
        'token': 'token',
        'permissions': 'permissions',
        'status': 'status',
        'description': 'description'
    }

    def __init__(self, org_id=None, user_id=None, token=None, permissions=None, status='active', description=None):  # noqa: E501,D401,D403
        """LegacyAuthorizationPostRequest - a model defined in OpenAPI."""  # noqa: E501
        AuthorizationUpdateRequest.__init__(self, status=status, description=description)  # noqa: E501

        self._org_id = None
        self._user_id = None
        self._token = None
        self._permissions = None
        self.discriminator = None

        if org_id is not None:
            self.org_id = org_id
        if user_id is not None:
            self.user_id = user_id
        if token is not None:
            self.token = token
        if permissions is not None:
            self.permissions = permissions

    @property
    def org_id(self):
        """Get the org_id of this LegacyAuthorizationPostRequest.

        ID of org that authorization is scoped to.

        :return: The org_id of this LegacyAuthorizationPostRequest.
        :rtype: str
        """  # noqa: E501
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Set the org_id of this LegacyAuthorizationPostRequest.

        ID of org that authorization is scoped to.

        :param org_id: The org_id of this LegacyAuthorizationPostRequest.
        :type: str
        """  # noqa: E501
        self._org_id = org_id

    @property
    def user_id(self):
        """Get the user_id of this LegacyAuthorizationPostRequest.

        ID of user that authorization is scoped to.

        :return: The user_id of this LegacyAuthorizationPostRequest.
        :rtype: str
        """  # noqa: E501
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Set the user_id of this LegacyAuthorizationPostRequest.

        ID of user that authorization is scoped to.

        :param user_id: The user_id of this LegacyAuthorizationPostRequest.
        :type: str
        """  # noqa: E501
        self._user_id = user_id

    @property
    def token(self):
        """Get the token of this LegacyAuthorizationPostRequest.

        Token (name) of the authorization

        :return: The token of this LegacyAuthorizationPostRequest.
        :rtype: str
        """  # noqa: E501
        return self._token

    @token.setter
    def token(self, token):
        """Set the token of this LegacyAuthorizationPostRequest.

        Token (name) of the authorization

        :param token: The token of this LegacyAuthorizationPostRequest.
        :type: str
        """  # noqa: E501
        self._token = token

    @property
    def permissions(self):
        """Get the permissions of this LegacyAuthorizationPostRequest.

        List of permissions for an auth.  An auth must have at least one Permission.

        :return: The permissions of this LegacyAuthorizationPostRequest.
        :rtype: list[Permission]
        """  # noqa: E501
        return self._permissions

    @permissions.setter
    def permissions(self, permissions):
        """Set the permissions of this LegacyAuthorizationPostRequest.

        List of permissions for an auth.  An auth must have at least one Permission.

        :param permissions: The permissions of this LegacyAuthorizationPostRequest.
        :type: list[Permission]
        """  # noqa: E501
        self._permissions = permissions

    def to_dict(self):
        """Return the model properties as a dict."""
        result = {}

        for attr, _ in self.openapi_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Return the string representation of the model."""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`."""
        return self.to_str()

    def __eq__(self, other):
        """Return true if both objects are equal."""
        if not isinstance(other, LegacyAuthorizationPostRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Return true if both objects are not equal."""
        return not self == other



"""Pandas date utils."""
from influxdb_client.client.util.date_utils import DateHelper
from influxdb_client.extras import pd


class PandasDateTimeHelper(DateHelper):
    """DateHelper that use Pandas library with nanosecond precision."""

    def parse_date(self, date_string: str):
        """Parse date string into `class 'pandas._libs.tslibs.timestamps.Timestamp`."""
        return pd.to_datetime(date_string)

    def to_nanoseconds(self, delta):
        """Get number of nanoseconds with nanos precision."""
        return super().to_nanoseconds(delta) + (delta.nanoseconds if hasattr(delta, 'nanoseconds') else 0)



"""
A bucket is a named location where time series data is stored.

All buckets have a retention policy, a duration of time that each data point persists.
A bucket belongs to an organization.
"""
import warnings

from influxdb_client import BucketsService, Bucket, PostBucketRequest, PatchBucketRequest
from influxdb_client.client.util.helpers import get_org_query_param
from influxdb_client.client._pages import _Paginated


class BucketsApi(object):
    """Implementation for '/api/v2/buckets' endpoint."""

    def __init__(self, influxdb_client):
        """Initialize defaults."""
        self._influxdb_client = influxdb_client
        self._buckets_service = BucketsService(influxdb_client.api_client)

    def create_bucket(self, bucket=None, bucket_name=None, org_id=None, retention_rules=None,
                      description=None, org=None) -> Bucket:
        """Create a bucket.

        :param Bucket|PostBucketRequest bucket: bucket to create
        :param bucket_name: bucket name
        :param description: bucket description
        :param org_id: org_id
        :param bucket_name: bucket name
        :param retention_rules: retention rules array or single BucketRetentionRules
        :param str, Organization org: specifies the organization for create the bucket;
                                      Take the ``ID``, ``Name`` or ``Organization``.
                                      If not specified the default value from ``InfluxDBClient.org`` is used.
        :return: Bucket
                 If the method is called asynchronously,
                 returns the request thread.
        """
        if retention_rules is None:
            retention_rules = []

        rules = []

        if isinstance(retention_rules, list):
            rules.extend(retention_rules)
        else:
            rules.append(retention_rules)

        if org_id is not None:
            warnings.warn("org_id is deprecated; use org", DeprecationWarning)

        if bucket is None:
            bucket = PostBucketRequest(name=bucket_name,
                                       retention_rules=rules,
                                       description=description,
                                       org_id=get_org_query_param(org=(org_id if org is None else org),
                                                                  client=self._influxdb_client,
                                                                  required_id=True))

        return self._buckets_service.post_buckets(post_bucket_request=bucket)

    def update_bucket(self, bucket: Bucket) -> Bucket:
        """Update a bucket.

        :param bucket: Bucket update to apply (required)
        :return: Bucket
        """
        request = PatchBucketRequest(name=bucket.name,
                                     description=bucket.description,
                                     retention_rules=bucket.retention_rules)

        return self._buckets_service.patch_buckets_id(bucket_id=bucket.id, patch_bucket_request=request)

    def delete_bucket(self, bucket):
        """Delete a bucket.

        :param bucket: bucket id or Bucket
        :return: Bucket
        """
        if isinstance(bucket, Bucket):
            bucket_id = bucket.id
        else:
            bucket_id = bucket

        return self._buckets_service.delete_buckets_id(bucket_id=bucket_id)

    def find_bucket_by_id(self, id):
        """Find bucket by ID.

        :param id:
        :return:
        """
        return self._buckets_service.get_buckets_id(id)

    def find_bucket_by_name(self, bucket_name):
        """Find bucket by name.

        :param bucket_name: bucket name
        :return: Bucket
        """
        buckets = self._buckets_service.get_buckets(name=bucket_name)

        if len(buckets.buckets) > 0:
            return buckets.buckets[0]
        else:
            return None

    def find_buckets(self, **kwargs):
        """List buckets.

        :key int offset: Offset for pagination
        :key int limit: Limit for pagination
        :key str after: The last resource ID from which to seek from (but not including).
                        This is to be used instead of `offset`.
        :key str org: The organization name.
        :key str org_id: The organization ID.
        :key str name: Only returns buckets with a specific name.
        :return: Buckets
        """
        return self._buckets_service.get_buckets(**kwargs)

    def find_buckets_iter(self, **kwargs):
        """Iterate over all buckets with pagination.

        :key str name: Only returns buckets with the specified name
        :key str org: The organization name.
        :key str org_id: The organization ID.
        :key str after: The last resource ID from which to seek from (but not including).
        :key int limit: the maximum number of buckets in one page
        :return: Buckets iterator
        """
        return _Paginated(self._buckets_service.get_buckets, lambda response: response.buckets).find_iter(**kwargs)
